package com.persagy.dmp.file.client;

import com.persagy.dmp.file.model.FileInfo;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.storage.config.FileFeignConfig;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

/**
 * 文件管理Client
 * @author Charlie Yu
 * @date 2021-05-15
 */
@FeignClient(name = "dmp-file", configuration = FileFeignConfig.class,path = "/file/",url = "${persagy.bdtp.file.service:}")
public interface FileManageClient {

    /**
     * 新增文件信息
     * @param fileInfo 文件信息
     * @return 文件信息
     */
    @PostMapping("insert")
    CommonResult<FileInfo> insert(@RequestBody FileInfo fileInfo);

    /**
     * 修改文件信息
     * @param fileInfo 文件信息
     * @return 文件信息
     */
    @PostMapping("update")
    CommonResult<FileInfo> update(@RequestBody FileInfo fileInfo);

    /**
     * 删除文件信息
     * @param id 文件信息
     * @return 文件信息
     */
    @PostMapping("delete")
    CommonResult<String> delete(@RequestBody String id);

    /**
     * 查询文件信息
     * @param id 文件信息
     * @return 文件信息
     */
    @PostMapping("load")
    CommonResult<FileInfo> load(@RequestBody String id);
    /**
     * 查询文件信息
     * @param id 文件信息
     * @return 文件信息
     */
    @PostMapping("queryByFileMd5")
    CommonResult<List<FileInfo>> queryByFileMd5(@RequestBody String id);
}
